import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_applicationautoscaling._jsii
import aws_cdk.aws_cloudwatch._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_kms._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.core._jsii
import aws_cdk.custom_resources._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-dynamodb", "1.51.0", __name__[0:-6], "aws-dynamodb@1.51.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
